@@ -19,29 +19,41 @@
 //!
 //! ```toml
 //! [dependencies]
-//! cqrs-es2 = "0.2.5"
+//! cqrs-es2 = "0.3.0"
 //! serde = { version = "^1.0.127", features = ["derive"] }
 //! serde_json = "^1.0.66"
 //! ```
 //!
 //! ## Usage
 //!
-//! Documentation [is available here](https://doc.rust-cqrs.org) along with an introduction to CQRS and event sourcing.
+//! Documentation [is available here](https://doc.rust-cqrs.org)
+//! along with an introduction to CQRS and event sourcing.
 //!
-//! A demo application [is available here](https://github.com/brgirgis/cqrs-es2-demo).
+//! Demo applications:
+//!
+//! - [RESTful](https://github.com/brgirgis/cqrs-restful-demo).
+//! - [gRPC](https://github.com/brgirgis/cqrs-grpc-demo).
 
 pub use crate::{
     aggregates::*,
+    commands::*,
+    errors::*,
     events::*,
     framework::*,
     queries::*,
     stores::*,
 };
 
+// Errors module holds the library error types.
+mod errors;
+
 // Aggregates module holds the central traits that define the
 // fundamental component of CQRS.
 mod aggregates;
 
+// Commands module provides the abstract domain commands.
+mod commands;
+
 // Events module provides the abstract domain events and associated
 // wrapper.
 mod events;
