@@ -7,14 +7,13 @@ use std::{
 };
 
 use crate::{
-    aggregates::{
-        Aggregate,
-        AggregateError,
-    },
+    aggregates::Aggregate,
+    errors::AggregateError,
     events::EventEnvelope,
-    EventStore,
 };
 
+use super::super::EventStore;
+
 use super::memory_store_aggregate_context::MemoryStoreAggregateContext;
 
 ///  Simple memory store only useful for testing purposes
@@ -37,6 +36,7 @@ impl<A: Aggregate> MemoryStore<A> {
     pub fn get_events(&self) -> Arc<LockedEventEnvelopeMap<A>> {
         Arc::clone(&self.events)
     }
+
     fn load_committed_events(
         &self,
         aggregate_id: String,
@@ -55,6 +55,7 @@ impl<A: Aggregate> MemoryStore<A> {
         };
         committed_events
     }
+
     fn aggregate_id(
         &self,
         events: &[EventEnvelope<A>],
