@@ -1,5 +1,6 @@
 use std::{
     collections::HashMap,
+    fmt::Debug,
     sync::{
         Arc,
         RwLock,
@@ -17,6 +18,7 @@ use cqrs_es2::{
     Aggregate,
     AggregateError,
     CqrsFramework,
+    DomainCommand,
     DomainEvent,
     EventEnvelope,
     EventStore,
@@ -105,10 +107,10 @@ impl Default for TestAggregate {
 
 #[derive(
     Debug,
-    Serialize,
-    Deserialize,
+    PartialEq,
     Clone,
-    PartialEq
+    Serialize,
+    Deserialize
 )]
 pub enum TestEvent {
     Created(Created),
@@ -118,10 +120,10 @@ pub enum TestEvent {
 
 #[derive(
     Debug,
-    Serialize,
-    Deserialize,
+    PartialEq,
     Clone,
-    PartialEq
+    Serialize,
+    Deserialize
 )]
 pub struct Created {
     pub id: String,
@@ -129,10 +131,10 @@ pub struct Created {
 
 #[derive(
     Debug,
-    Serialize,
-    Deserialize,
+    PartialEq,
     Clone,
-    PartialEq
+    Serialize,
+    Deserialize
 )]
 pub struct Tested {
     pub test_name: String,
@@ -140,10 +142,10 @@ pub struct Tested {
 
 #[derive(
     Debug,
-    Serialize,
-    Deserialize,
+    PartialEq,
     Clone,
-    PartialEq
+    Serialize,
+    Deserialize
 )]
 pub struct SomethingElse {
     pub description: String,
@@ -151,24 +153,30 @@ pub struct SomethingElse {
 
 impl DomainEvent for TestEvent {}
 
+#[derive(Debug, PartialEq)]
 pub enum TestCommand {
     CreateTest(CreateTest),
     ConfirmTest(ConfirmTest),
     DoSomethingElse(DoSomethingElse),
 }
 
+#[derive(Debug, PartialEq)]
 pub struct CreateTest {
     pub id: String,
 }
 
+#[derive(Debug, PartialEq)]
 pub struct ConfirmTest {
     pub test_name: String,
 }
 
+#[derive(Debug, PartialEq)]
 pub struct DoSomethingElse {
     pub description: String,
 }
 
+impl DomainCommand for TestCommand {}
+
 struct TestView {
     events: Arc<RwLock<Vec<EventEnvelope<TestAggregate>>>>,
 }
